@@ -10,11 +10,11 @@ Usage::
     client: AppflowClient = boto3.client("appflow")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_appflow.literals import ConnectionMode, ConnectorType
 from mypy_boto3_appflow.type_defs import (
     ConnectorProfileConfigTypeDef,
     CreateConnectorProfileResponseTypeDef,
@@ -37,12 +37,6 @@ from mypy_boto3_appflow.type_defs import (
     UpdateFlowResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("AppflowClient",)
 
 
@@ -82,30 +76,8 @@ class AppflowClient:
     def create_connector_profile(
         self,
         connectorProfileName: str,
-        connectorType: Literal[
-            "Salesforce",
-            "Singular",
-            "Slack",
-            "Redshift",
-            "S3",
-            "Marketo",
-            "Googleanalytics",
-            "Zendesk",
-            "Servicenow",
-            "Datadog",
-            "Trendmicro",
-            "Snowflake",
-            "Dynatrace",
-            "Infornexus",
-            "Amplitude",
-            "Veeva",
-            "EventBridge",
-            "LookoutMetrics",
-            "Upsolver",
-            "Honeycode",
-            "CustomerProfiles",
-        ],
-        connectionMode: Literal["Public", "Private"],
+        connectorType: ConnectorType,
+        connectionMode: ConnectionMode,
         connectorProfileConfig: ConnectorProfileConfigTypeDef,
         kmsArn: str = None,
     ) -> CreateConnectorProfileResponseTypeDef:
@@ -143,29 +115,7 @@ class AppflowClient:
     def describe_connector_entity(
         self,
         connectorEntityName: str,
-        connectorType: Literal[
-            "Salesforce",
-            "Singular",
-            "Slack",
-            "Redshift",
-            "S3",
-            "Marketo",
-            "Googleanalytics",
-            "Zendesk",
-            "Servicenow",
-            "Datadog",
-            "Trendmicro",
-            "Snowflake",
-            "Dynatrace",
-            "Infornexus",
-            "Amplitude",
-            "Veeva",
-            "EventBridge",
-            "LookoutMetrics",
-            "Upsolver",
-            "Honeycode",
-            "CustomerProfiles",
-        ] = None,
+        connectorType: ConnectorType = None,
         connectorProfileName: str = None,
     ) -> DescribeConnectorEntityResponseTypeDef:
         """
@@ -175,29 +125,7 @@ class AppflowClient:
     def describe_connector_profiles(
         self,
         connectorProfileNames: List[str] = None,
-        connectorType: Literal[
-            "Salesforce",
-            "Singular",
-            "Slack",
-            "Redshift",
-            "S3",
-            "Marketo",
-            "Googleanalytics",
-            "Zendesk",
-            "Servicenow",
-            "Datadog",
-            "Trendmicro",
-            "Snowflake",
-            "Dynatrace",
-            "Infornexus",
-            "Amplitude",
-            "Veeva",
-            "EventBridge",
-            "LookoutMetrics",
-            "Upsolver",
-            "Honeycode",
-            "CustomerProfiles",
-        ] = None,
+        connectorType: ConnectorType = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> DescribeConnectorProfilesResponseTypeDef:
@@ -206,33 +134,7 @@ class AppflowClient:
         """
 
     def describe_connectors(
-        self,
-        connectorTypes: List[
-            Literal[
-                "Salesforce",
-                "Singular",
-                "Slack",
-                "Redshift",
-                "S3",
-                "Marketo",
-                "Googleanalytics",
-                "Zendesk",
-                "Servicenow",
-                "Datadog",
-                "Trendmicro",
-                "Snowflake",
-                "Dynatrace",
-                "Infornexus",
-                "Amplitude",
-                "Veeva",
-                "EventBridge",
-                "LookoutMetrics",
-                "Upsolver",
-                "Honeycode",
-                "CustomerProfiles",
-            ]
-        ] = None,
-        nextToken: str = None,
+        self, connectorTypes: List[ConnectorType] = None, nextToken: str = None
     ) -> DescribeConnectorsResponseTypeDef:
         """
         [Client.describe_connectors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/appflow.html#Appflow.Client.describe_connectors)
@@ -264,29 +166,7 @@ class AppflowClient:
     def list_connector_entities(
         self,
         connectorProfileName: str = None,
-        connectorType: Literal[
-            "Salesforce",
-            "Singular",
-            "Slack",
-            "Redshift",
-            "S3",
-            "Marketo",
-            "Googleanalytics",
-            "Zendesk",
-            "Servicenow",
-            "Datadog",
-            "Trendmicro",
-            "Snowflake",
-            "Dynatrace",
-            "Infornexus",
-            "Amplitude",
-            "Veeva",
-            "EventBridge",
-            "LookoutMetrics",
-            "Upsolver",
-            "Honeycode",
-            "CustomerProfiles",
-        ] = None,
+        connectorType: ConnectorType = None,
         entitiesPath: str = None,
     ) -> ListConnectorEntitiesResponseTypeDef:
         """
@@ -326,7 +206,7 @@ class AppflowClient:
     def update_connector_profile(
         self,
         connectorProfileName: str,
-        connectionMode: Literal["Public", "Private"],
+        connectionMode: ConnectionMode,
         connectorProfileConfig: ConnectorProfileConfigTypeDef,
     ) -> UpdateConnectorProfileResponseTypeDef:
         """
