@@ -13,10 +13,38 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_appflow.literals import (
+    AggregationType,
+    AmplitudeConnectorOperator,
+    ConnectionMode,
+    ConnectorType,
+    DatadogConnectorOperator,
+    DataPullMode,
+    DynatraceConnectorOperator,
+    ExecutionStatus,
+    FileType,
+    FlowStatus,
+    GoogleAnalyticsConnectorOperator,
+    InforNexusConnectorOperator,
+    MarketoConnectorOperator,
+    Operator,
+    OperatorPropertiesKeys,
+    PrefixFormat,
+    PrefixType,
+    S3ConnectorOperator,
+    SalesforceConnectorOperator,
+    ScheduleFrequencyType,
+    ServiceNowConnectorOperator,
+    SingularConnectorOperator,
+    SlackConnectorOperator,
+    TaskType,
+    TrendmicroConnectorOperator,
+    TriggerType,
+    VeevaConnectorOperator,
+    WriteOperationType,
+    ZendeskConnectorOperator,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -130,7 +158,7 @@ __all__ = (
 )
 
 AggregationConfigTypeDef = TypedDict(
-    "AggregationConfigTypeDef", {"aggregationType": Literal["None", "SingleFile"]}, total=False
+    "AggregationConfigTypeDef", {"aggregationType": AggregationType}, total=False
 )
 
 AmplitudeConnectorProfileCredentialsTypeDef = TypedDict(
@@ -144,37 +172,11 @@ ConnectorConfigurationTypeDef = TypedDict(
     {
         "canUseAsSource": bool,
         "canUseAsDestination": bool,
-        "supportedDestinationConnectors": List[
-            Literal[
-                "Salesforce",
-                "Singular",
-                "Slack",
-                "Redshift",
-                "S3",
-                "Marketo",
-                "Googleanalytics",
-                "Zendesk",
-                "Servicenow",
-                "Datadog",
-                "Trendmicro",
-                "Snowflake",
-                "Dynatrace",
-                "Infornexus",
-                "Amplitude",
-                "Veeva",
-                "EventBridge",
-                "LookoutMetrics",
-                "Upsolver",
-                "Honeycode",
-                "CustomerProfiles",
-            ]
-        ],
-        "supportedSchedulingFrequencies": List[
-            Literal["BYMINUTE", "HOURLY", "DAILY", "WEEKLY", "MONTHLY", "ONCE"]
-        ],
+        "supportedDestinationConnectors": List[ConnectorType],
+        "supportedSchedulingFrequencies": List[ScheduleFrequencyType],
         "isPrivateLinkEnabled": bool,
         "isPrivateLinkEndpointUrlRequired": bool,
-        "supportedTriggerTypes": List[Literal["Scheduled", "Event", "OnDemand"]],
+        "supportedTriggerTypes": List[TriggerType],
         "connectorMetadata": "ConnectorMetadataTypeDef",
     },
     total=False,
@@ -246,237 +248,20 @@ ConnectorOAuthRequestTypeDef = TypedDict(
 ConnectorOperatorTypeDef = TypedDict(
     "ConnectorOperatorTypeDef",
     {
-        "Amplitude": Literal["BETWEEN"],
-        "Datadog": Literal[
-            "PROJECTION",
-            "BETWEEN",
-            "EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "Dynatrace": Literal[
-            "PROJECTION",
-            "BETWEEN",
-            "EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "GoogleAnalytics": Literal["PROJECTION", "BETWEEN"],
-        "InforNexus": Literal[
-            "PROJECTION",
-            "BETWEEN",
-            "EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "Marketo": Literal[
-            "PROJECTION",
-            "LESS_THAN",
-            "GREATER_THAN",
-            "BETWEEN",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "S3": Literal[
-            "PROJECTION",
-            "LESS_THAN",
-            "GREATER_THAN",
-            "BETWEEN",
-            "LESS_THAN_OR_EQUAL_TO",
-            "GREATER_THAN_OR_EQUAL_TO",
-            "EQUAL_TO",
-            "NOT_EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "Salesforce": Literal[
-            "PROJECTION",
-            "LESS_THAN",
-            "CONTAINS",
-            "GREATER_THAN",
-            "BETWEEN",
-            "LESS_THAN_OR_EQUAL_TO",
-            "GREATER_THAN_OR_EQUAL_TO",
-            "EQUAL_TO",
-            "NOT_EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "ServiceNow": Literal[
-            "PROJECTION",
-            "CONTAINS",
-            "LESS_THAN",
-            "GREATER_THAN",
-            "BETWEEN",
-            "LESS_THAN_OR_EQUAL_TO",
-            "GREATER_THAN_OR_EQUAL_TO",
-            "EQUAL_TO",
-            "NOT_EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "Singular": Literal[
-            "PROJECTION",
-            "EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "Slack": Literal[
-            "PROJECTION",
-            "LESS_THAN",
-            "GREATER_THAN",
-            "BETWEEN",
-            "LESS_THAN_OR_EQUAL_TO",
-            "GREATER_THAN_OR_EQUAL_TO",
-            "EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "Trendmicro": Literal[
-            "PROJECTION",
-            "EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "Veeva": Literal[
-            "PROJECTION",
-            "LESS_THAN",
-            "GREATER_THAN",
-            "CONTAINS",
-            "BETWEEN",
-            "LESS_THAN_OR_EQUAL_TO",
-            "GREATER_THAN_OR_EQUAL_TO",
-            "EQUAL_TO",
-            "NOT_EQUAL_TO",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
-        "Zendesk": Literal[
-            "PROJECTION",
-            "GREATER_THAN",
-            "ADDITION",
-            "MULTIPLICATION",
-            "DIVISION",
-            "SUBTRACTION",
-            "MASK_ALL",
-            "MASK_FIRST_N",
-            "MASK_LAST_N",
-            "VALIDATE_NON_NULL",
-            "VALIDATE_NON_ZERO",
-            "VALIDATE_NON_NEGATIVE",
-            "VALIDATE_NUMERIC",
-            "NO_OP",
-        ],
+        "Amplitude": AmplitudeConnectorOperator,
+        "Datadog": DatadogConnectorOperator,
+        "Dynatrace": DynatraceConnectorOperator,
+        "GoogleAnalytics": GoogleAnalyticsConnectorOperator,
+        "InforNexus": InforNexusConnectorOperator,
+        "Marketo": MarketoConnectorOperator,
+        "S3": S3ConnectorOperator,
+        "Salesforce": SalesforceConnectorOperator,
+        "ServiceNow": ServiceNowConnectorOperator,
+        "Singular": SingularConnectorOperator,
+        "Slack": SlackConnectorOperator,
+        "Trendmicro": TrendmicroConnectorOperator,
+        "Veeva": VeevaConnectorOperator,
+        "Zendesk": ZendeskConnectorOperator,
     },
     total=False,
 )
@@ -532,30 +317,8 @@ ConnectorProfileTypeDef = TypedDict(
     {
         "connectorProfileArn": str,
         "connectorProfileName": str,
-        "connectorType": Literal[
-            "Salesforce",
-            "Singular",
-            "Slack",
-            "Redshift",
-            "S3",
-            "Marketo",
-            "Googleanalytics",
-            "Zendesk",
-            "Servicenow",
-            "Datadog",
-            "Trendmicro",
-            "Snowflake",
-            "Dynatrace",
-            "Infornexus",
-            "Amplitude",
-            "Veeva",
-            "EventBridge",
-            "LookoutMetrics",
-            "Upsolver",
-            "Honeycode",
-            "CustomerProfiles",
-        ],
-        "connectionMode": Literal["Public", "Private"],
+        "connectorType": ConnectorType,
+        "connectionMode": ConnectionMode,
         "credentialsArn": str,
         "connectorProfileProperties": "ConnectorProfilePropertiesTypeDef",
         "createdAt": datetime,
@@ -613,7 +376,7 @@ DestinationFieldPropertiesTypeDef = TypedDict(
         "isNullable": bool,
         "isUpsertable": bool,
         "isUpdatable": bool,
-        "supportedWriteOperations": List[Literal["INSERT", "UPSERT", "UPDATE"]],
+        "supportedWriteOperations": List[WriteOperationType],
     },
     total=False,
 )
@@ -621,29 +384,7 @@ DestinationFieldPropertiesTypeDef = TypedDict(
 _RequiredDestinationFlowConfigTypeDef = TypedDict(
     "_RequiredDestinationFlowConfigTypeDef",
     {
-        "connectorType": Literal[
-            "Salesforce",
-            "Singular",
-            "Slack",
-            "Redshift",
-            "S3",
-            "Marketo",
-            "Googleanalytics",
-            "Zendesk",
-            "Servicenow",
-            "Datadog",
-            "Trendmicro",
-            "Snowflake",
-            "Dynatrace",
-            "Infornexus",
-            "Amplitude",
-            "Veeva",
-            "EventBridge",
-            "LookoutMetrics",
-            "Upsolver",
-            "Honeycode",
-            "CustomerProfiles",
-        ],
+        "connectorType": ConnectorType,
         "destinationConnectorProperties": "DestinationConnectorPropertiesTypeDef",
     },
 )
@@ -700,7 +441,7 @@ ExecutionDetailsTypeDef = TypedDict(
     {
         "mostRecentExecutionMessage": str,
         "mostRecentExecutionTime": datetime,
-        "mostRecentExecutionStatus": Literal["InProgress", "Successful", "Error"],
+        "mostRecentExecutionStatus": ExecutionStatus,
     },
     total=False,
 )
@@ -709,7 +450,7 @@ ExecutionRecordTypeDef = TypedDict(
     "ExecutionRecordTypeDef",
     {
         "executionId": str,
-        "executionStatus": Literal["InProgress", "Successful", "Error"],
+        "executionStatus": ExecutionStatus,
         "executionResult": "ExecutionResultTypeDef",
         "startedAt": datetime,
         "lastUpdatedAt": datetime,
@@ -731,35 +472,7 @@ ExecutionResultTypeDef = TypedDict(
 )
 
 _RequiredFieldTypeDetailsTypeDef = TypedDict(
-    "_RequiredFieldTypeDetailsTypeDef",
-    {
-        "fieldType": str,
-        "filterOperators": List[
-            Literal[
-                "PROJECTION",
-                "LESS_THAN",
-                "GREATER_THAN",
-                "CONTAINS",
-                "BETWEEN",
-                "LESS_THAN_OR_EQUAL_TO",
-                "GREATER_THAN_OR_EQUAL_TO",
-                "EQUAL_TO",
-                "NOT_EQUAL_TO",
-                "ADDITION",
-                "MULTIPLICATION",
-                "DIVISION",
-                "SUBTRACTION",
-                "MASK_ALL",
-                "MASK_FIRST_N",
-                "MASK_LAST_N",
-                "VALIDATE_NON_NULL",
-                "VALIDATE_NON_ZERO",
-                "VALIDATE_NON_NEGATIVE",
-                "VALIDATE_NUMERIC",
-                "NO_OP",
-            ]
-        ],
-    },
+    "_RequiredFieldTypeDetailsTypeDef", {"fieldType": str, "filterOperators": List[Operator]}
 )
 _OptionalFieldTypeDetailsTypeDef = TypedDict(
     "_OptionalFieldTypeDetailsTypeDef", {"supportedValues": List[str]}, total=False
@@ -776,54 +489,10 @@ FlowDefinitionTypeDef = TypedDict(
         "flowArn": str,
         "description": str,
         "flowName": str,
-        "flowStatus": Literal["Active", "Deprecated", "Deleted", "Draft", "Errored", "Suspended"],
-        "sourceConnectorType": Literal[
-            "Salesforce",
-            "Singular",
-            "Slack",
-            "Redshift",
-            "S3",
-            "Marketo",
-            "Googleanalytics",
-            "Zendesk",
-            "Servicenow",
-            "Datadog",
-            "Trendmicro",
-            "Snowflake",
-            "Dynatrace",
-            "Infornexus",
-            "Amplitude",
-            "Veeva",
-            "EventBridge",
-            "LookoutMetrics",
-            "Upsolver",
-            "Honeycode",
-            "CustomerProfiles",
-        ],
-        "destinationConnectorType": Literal[
-            "Salesforce",
-            "Singular",
-            "Slack",
-            "Redshift",
-            "S3",
-            "Marketo",
-            "Googleanalytics",
-            "Zendesk",
-            "Servicenow",
-            "Datadog",
-            "Trendmicro",
-            "Snowflake",
-            "Dynatrace",
-            "Infornexus",
-            "Amplitude",
-            "Veeva",
-            "EventBridge",
-            "LookoutMetrics",
-            "Upsolver",
-            "Honeycode",
-            "CustomerProfiles",
-        ],
-        "triggerType": Literal["Scheduled", "Event", "OnDemand"],
+        "flowStatus": FlowStatus,
+        "sourceConnectorType": ConnectorType,
+        "destinationConnectorType": ConnectorType,
+        "triggerType": TriggerType,
         "createdAt": datetime,
         "lastUpdatedAt": datetime,
         "createdBy": str,
@@ -925,12 +594,7 @@ MarketoConnectorProfilePropertiesTypeDef = TypedDict(
 MarketoSourcePropertiesTypeDef = TypedDict("MarketoSourcePropertiesTypeDef", {"object": str})
 
 PrefixConfigTypeDef = TypedDict(
-    "PrefixConfigTypeDef",
-    {
-        "prefixType": Literal["FILENAME", "PATH", "PATH_AND_FILENAME"],
-        "prefixFormat": Literal["YEAR", "MONTH", "DAY", "HOUR", "MINUTE"],
-    },
-    total=False,
+    "PrefixConfigTypeDef", {"prefixType": PrefixType, "prefixFormat": PrefixFormat}, total=False
 )
 
 RedshiftConnectorProfileCredentialsTypeDef = TypedDict(
@@ -988,7 +652,7 @@ class S3DestinationPropertiesTypeDef(
 S3OutputFormatConfigTypeDef = TypedDict(
     "S3OutputFormatConfigTypeDef",
     {
-        "fileType": Literal["CSV", "JSON", "PARQUET"],
+        "fileType": FileType,
         "prefixConfig": "PrefixConfigTypeDef",
         "aggregationConfig": "AggregationConfigTypeDef",
     },
@@ -1034,7 +698,7 @@ _OptionalSalesforceDestinationPropertiesTypeDef = TypedDict(
     {
         "idFieldNames": List[str],
         "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
-        "writeOperationType": Literal["INSERT", "UPSERT", "UPDATE"],
+        "writeOperationType": WriteOperationType,
     },
     total=False,
 )
@@ -1072,7 +736,7 @@ _RequiredScheduledTriggerPropertiesTypeDef = TypedDict(
 _OptionalScheduledTriggerPropertiesTypeDef = TypedDict(
     "_OptionalScheduledTriggerPropertiesTypeDef",
     {
-        "dataPullMode": Literal["Incremental", "Complete"],
+        "dataPullMode": DataPullMode,
         "scheduleStartTime": datetime,
         "scheduleEndTime": datetime,
         "timezone": str,
@@ -1200,29 +864,7 @@ SourceFieldPropertiesTypeDef = TypedDict(
 _RequiredSourceFlowConfigTypeDef = TypedDict(
     "_RequiredSourceFlowConfigTypeDef",
     {
-        "connectorType": Literal[
-            "Salesforce",
-            "Singular",
-            "Slack",
-            "Redshift",
-            "S3",
-            "Marketo",
-            "Googleanalytics",
-            "Zendesk",
-            "Servicenow",
-            "Datadog",
-            "Trendmicro",
-            "Snowflake",
-            "Dynatrace",
-            "Infornexus",
-            "Amplitude",
-            "Veeva",
-            "EventBridge",
-            "LookoutMetrics",
-            "Upsolver",
-            "Honeycode",
-            "CustomerProfiles",
-        ],
+        "connectorType": ConnectorType,
         "sourceConnectorProperties": "SourceConnectorPropertiesTypeDef",
     },
 )
@@ -1242,36 +884,14 @@ SupportedFieldTypeDetailsTypeDef = TypedDict(
 )
 
 _RequiredTaskTypeDef = TypedDict(
-    "_RequiredTaskTypeDef",
-    {
-        "sourceFields": List[str],
-        "taskType": Literal["Arithmetic", "Filter", "Map", "Mask", "Merge", "Truncate", "Validate"],
-    },
+    "_RequiredTaskTypeDef", {"sourceFields": List[str], "taskType": TaskType}
 )
 _OptionalTaskTypeDef = TypedDict(
     "_OptionalTaskTypeDef",
     {
         "connectorOperator": "ConnectorOperatorTypeDef",
         "destinationField": str,
-        "taskProperties": Dict[
-            Literal[
-                "VALUE",
-                "VALUES",
-                "DATA_TYPE",
-                "UPPER_BOUND",
-                "LOWER_BOUND",
-                "SOURCE_DATA_TYPE",
-                "DESTINATION_DATA_TYPE",
-                "VALIDATION_ACTION",
-                "MASK_VALUE",
-                "MASK_LENGTH",
-                "TRUNCATE_LENGTH",
-                "MATH_OPERATION_FIELDS_ORDER",
-                "CONCAT_FORMAT",
-                "SUBFIELD_CATEGORY_MAP",
-            ],
-            str,
-        ],
+        "taskProperties": Dict[OperatorPropertiesKeys, str],
     },
     total=False,
 )
@@ -1288,7 +908,7 @@ TrendmicroConnectorProfileCredentialsTypeDef = TypedDict(
 TrendmicroSourcePropertiesTypeDef = TypedDict("TrendmicroSourcePropertiesTypeDef", {"object": str})
 
 _RequiredTriggerConfigTypeDef = TypedDict(
-    "_RequiredTriggerConfigTypeDef", {"triggerType": Literal["Scheduled", "Event", "OnDemand"]}
+    "_RequiredTriggerConfigTypeDef", {"triggerType": TriggerType}
 )
 _OptionalTriggerConfigTypeDef = TypedDict(
     "_OptionalTriggerConfigTypeDef", {"triggerProperties": "TriggerPropertiesTypeDef"}, total=False
@@ -1323,10 +943,7 @@ _RequiredUpsolverS3OutputFormatConfigTypeDef = TypedDict(
 )
 _OptionalUpsolverS3OutputFormatConfigTypeDef = TypedDict(
     "_OptionalUpsolverS3OutputFormatConfigTypeDef",
-    {
-        "fileType": Literal["CSV", "JSON", "PARQUET"],
-        "aggregationConfig": "AggregationConfigTypeDef",
-    },
+    {"fileType": FileType, "aggregationConfig": "AggregationConfigTypeDef"},
     total=False,
 )
 
@@ -1376,7 +993,7 @@ _OptionalZendeskDestinationPropertiesTypeDef = TypedDict(
     {
         "idFieldNames": List[str],
         "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
-        "writeOperationType": Literal["INSERT", "UPSERT", "UPDATE"],
+        "writeOperationType": WriteOperationType,
     },
     total=False,
 )
@@ -1407,12 +1024,7 @@ CreateConnectorProfileResponseTypeDef = TypedDict(
 )
 
 CreateFlowResponseTypeDef = TypedDict(
-    "CreateFlowResponseTypeDef",
-    {
-        "flowArn": str,
-        "flowStatus": Literal["Active", "Deprecated", "Deleted", "Draft", "Errored", "Suspended"],
-    },
-    total=False,
+    "CreateFlowResponseTypeDef", {"flowArn": str, "flowStatus": FlowStatus}, total=False
 )
 
 DescribeConnectorEntityResponseTypeDef = TypedDict(
@@ -1429,32 +1041,7 @@ DescribeConnectorProfilesResponseTypeDef = TypedDict(
 DescribeConnectorsResponseTypeDef = TypedDict(
     "DescribeConnectorsResponseTypeDef",
     {
-        "connectorConfigurations": Dict[
-            Literal[
-                "Salesforce",
-                "Singular",
-                "Slack",
-                "Redshift",
-                "S3",
-                "Marketo",
-                "Googleanalytics",
-                "Zendesk",
-                "Servicenow",
-                "Datadog",
-                "Trendmicro",
-                "Snowflake",
-                "Dynatrace",
-                "Infornexus",
-                "Amplitude",
-                "Veeva",
-                "EventBridge",
-                "LookoutMetrics",
-                "Upsolver",
-                "Honeycode",
-                "CustomerProfiles",
-            ],
-            "ConnectorConfigurationTypeDef",
-        ],
+        "connectorConfigurations": Dict[ConnectorType, "ConnectorConfigurationTypeDef"],
         "nextToken": str,
     },
     total=False,
@@ -1473,7 +1060,7 @@ DescribeFlowResponseTypeDef = TypedDict(
         "description": str,
         "flowName": str,
         "kmsArn": str,
-        "flowStatus": Literal["Active", "Deprecated", "Deleted", "Draft", "Errored", "Suspended"],
+        "flowStatus": FlowStatus,
         "flowStatusMessage": str,
         "sourceFlowConfig": "SourceFlowConfigTypeDef",
         "destinationFlowConfigList": List["DestinationFlowConfigTypeDef"],
@@ -1506,21 +1093,12 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 
 StartFlowResponseTypeDef = TypedDict(
     "StartFlowResponseTypeDef",
-    {
-        "flowArn": str,
-        "flowStatus": Literal["Active", "Deprecated", "Deleted", "Draft", "Errored", "Suspended"],
-        "executionId": str,
-    },
+    {"flowArn": str, "flowStatus": FlowStatus, "executionId": str},
     total=False,
 )
 
 StopFlowResponseTypeDef = TypedDict(
-    "StopFlowResponseTypeDef",
-    {
-        "flowArn": str,
-        "flowStatus": Literal["Active", "Deprecated", "Deleted", "Draft", "Errored", "Suspended"],
-    },
-    total=False,
+    "StopFlowResponseTypeDef", {"flowArn": str, "flowStatus": FlowStatus}, total=False
 )
 
 UpdateConnectorProfileResponseTypeDef = TypedDict(
@@ -1528,7 +1106,5 @@ UpdateConnectorProfileResponseTypeDef = TypedDict(
 )
 
 UpdateFlowResponseTypeDef = TypedDict(
-    "UpdateFlowResponseTypeDef",
-    {"flowStatus": Literal["Active", "Deprecated", "Deleted", "Draft", "Errored", "Suspended"]},
-    total=False,
+    "UpdateFlowResponseTypeDef", {"flowStatus": FlowStatus}, total=False
 )
